==> opencascade-7.7.2_4.arm64_sonoma.bottle.tar.gz: opencascade/7.7.2_4/share/doc/opencascade/overview/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Open CASCADE Technology", "index.html", [
    [ "Introduction", "index.html", "index" ],
    [ "Tutorials and Samples", "samples.html", "samples" ],
    [ "Build, Debug and Upgrade", "build_upgrade.html", "build_upgrade" ],
    [ "User Guides", "user_guides.html", "user_guides" ],
    [ "Specifications", "specification.html", "specification" ],
    [ "Contribution", "contribution.html", "contribution" ],
    [ "License", "occt_public_license.html", [
      [ "GNU LESSER GENERAL PUBLIC LICENSE", "occt_public_license.html#license_lgpl_21", [
        [ "Preamble", "occt_public_license.html#autotoc_md407", null ],
        [ "TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION", "occt_public_license.html#autotoc_md408", null ],
        [ "END OF TERMS AND CONDITIONS", "occt_public_license.html#autotoc_md409", null ],
        [ "How to Apply These Terms to Your New Libraries", "occt_public_license.html#autotoc_md410", null ]
      ] ],
      [ "OPEN CASCADE EXCEPTION", "occt_public_license.html#occt_lgpl_exception", [
        [ "Open CASCADE Exception (version 1.0) to GNU LGPL version 2.1.", "occt_public_license.html#autotoc_md411", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"build_upgrade.html",
"occt__upgrade.html#upgrade_occt720",
"occt_contribution__tests.html#testmanual_5_1_17",
"occt_user_guides__inspector.html#occt_inspector_2_5_2",
"occt_user_guides__modeling_data.html#occt_modat_5",
"occt_user_guides__shape_healing.html#occt_shg_6_2",
"occt_user_guides__test_harness.html#occt_draw_4_3_5",
"occt_user_guides__test_harness.html#occt_draw_7_2_3",
"occt_user_guides__visualization.html#autotoc_md201",
"specification__boolean_operations.html#autotoc_md314",
"specification__brep_format.html#specification__brep_format_5_4"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> opencascade-7.8.1_1.arm64_sonoma.bottle.tar.gz: opencascade/7.8.1_1/share/doc/opencascade/overview/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Open CASCADE Technology", "index.html", [
    [ "Introduction", "index.html", "index" ],
    [ "Tutorials and Samples", "samples.html", "samples" ],
    [ "Build, Debug and Upgrade", "build_upgrade.html", "build_upgrade" ],
    [ "User Guides", "user_guides.html", "user_guides" ],
    [ "Specifications", "specification.html", "specification" ],
    [ "Contribution", "contribution.html", "contribution" ],
    [ "License", "occt_public_license.html", [
      [ "GNU LESSER GENERAL PUBLIC LICENSE", "occt_public_license.html#license_lgpl_21", [
        [ "Preamble", "occt_public_license.html#autotoc_md407", null ],
        [ "TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION", "occt_public_license.html#autotoc_md408", null ],
        [ "END OF TERMS AND CONDITIONS", "occt_public_license.html#autotoc_md409", null ],
        [ "How to Apply These Terms to Your New Libraries", "occt_public_license.html#autotoc_md410", null ]
      ] ],
      [ "OPEN CASCADE EXCEPTION", "occt_public_license.html#occt_lgpl_exception", [
        [ "Open CASCADE Exception (version 1.0) to GNU LGPL version 2.1.", "occt_public_license.html#autotoc_md411", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"build_upgrade.html",
"occt__upgrade.html#upgrade_occt700_correction_of_texture",
"occt_contribution__tests.html#testmanual_5_1",
"occt_user_guides__inspector.html#occt_inspector_2_3_5",
"occt_user_guides__modeling_data.html#occt_modat_2",
"occt_user_guides__shape_healing.html#occt_shg_5_",
"occt_user_guides__test_harness.html#occt_draw_4_3_2",
"occt_user_guides__test_harness.html#occt_draw_7_1_4",
"occt_user_guides__visualization.html#autotoc_md192",
"specification__boolean_operations.html#autotoc_md305",
"specification__brep_format.html#specification__brep_format_5_3_1"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
